Method: Aws::STS::Client#get_session_token
- Defined in:
- lib/aws-sdk-sts/client.rb
#get_session_token(params = {}) ⇒ Types::GetSessionTokenResponse
Returns a set of temporary credentials for an AWS account or IAM user. The credentials consist of an access key ID, a secret access key, and a security token. Typically, you use GetSessionToken if you want to use MFA to protect programmatic calls to specific AWS API operations like Amazon EC2 StopInstances. MFA-enabled IAM users would need to call GetSessionToken and submit an MFA code that is associated with their MFA device. Using the temporary security credentials that are returned from the call, IAM users can then make programmatic calls to API operations that require MFA authentication. If you do not supply a correct MFA code, then the API returns an access denied error. For a comparison of GetSessionToken with the other API operations that produce temporary credentials, see [Requesting Temporary Security Credentials][1] and [Comparing the AWS STS API operations][2] in the *IAM User Guide*.
**Session Duration**
The GetSessionToken operation must be called by using the long-term AWS security credentials of the AWS account root user or an IAM user. Credentials that are created by IAM users are valid for the duration that you specify. This duration can range from 900 seconds (15 minutes) up to a maximum of 129,600 seconds (36 hours), with a default of 43,200 seconds (12 hours). Credentials based on account credentials can range from 900 seconds (15 minutes) up to 3,600 seconds (1 hour), with a default of 1 hour.
Permissions
The temporary security credentials created by GetSessionToken can be used to make API calls to any AWS service with the following exceptions:
-
You cannot call any IAM API operations unless MFA authentication information is included in the request.
-
You cannot call any STS API except
AssumeRoleorGetCallerIdentity.
<note markdown=“1”> We recommend that you do not call GetSessionToken with AWS account root user credentials. Instead, follow our [best practices][3] by creating one or more IAM users, giving them the necessary permissions, and using IAM users for everyday interaction with AWS.
</note>
The credentials that are returned by GetSessionToken are based on permissions associated with the user whose credentials were used to call the operation. If GetSessionToken is called using AWS account root user credentials, the temporary credentials have root user permissions. Similarly, if GetSessionToken is called using the credentials of an IAM user, the temporary credentials have the same permissions as the IAM user.
For more information about using GetSessionToken to create temporary credentials, go to [Temporary Credentials for Users in Untrusted Environments][4] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#stsapi_comparison [3]: docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html#create-iam-users [4]: docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_getsessiontoken
2189 2190 2191 2192 |
# File 'lib/aws-sdk-sts/client.rb', line 2189 def get_session_token(params = {}, = {}) req = build_request(:get_session_token, params) req.send_request() end |