Class: Aws::Endpoints::Reference Private

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-core/endpoints/reference.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

This class is deprecated. It is used by the Runtime endpoint resolution approach. It has been replaced by a code generated approach in each service gem. It can be removed in a new major version. It has to exist because old service gems can use a new core version.

API:

  • private

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(ref:) ⇒ Reference

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Reference.

API:

  • private



12
13
14
# File 'lib/aws-sdk-core/endpoints/reference.rb', line 12

def initialize(ref:)
  @ref = ref
end

Instance Attribute Details

#refObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



16
17
18
# File 'lib/aws-sdk-core/endpoints/reference.rb', line 16

def ref
  @ref
end

Instance Method Details

#resolve(parameters, assigns) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



18
19
20
21
22
23
24
25
26
27
28
# File 'lib/aws-sdk-core/endpoints/reference.rb', line 18

def resolve(parameters, assigns)
  if parameters.class.singleton_class::PARAM_MAP.key?(@ref)
    member_name = parameters.class.singleton_class::PARAM_MAP[@ref]
    parameters[member_name]
  elsif assigns.key?(@ref)
    assigns[@ref]
  else
    raise ArgumentError,
          "Reference #{@ref} is not a param or an assigned value."
  end
end