Class: Aws::Endpoints::Rule Private

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-core/endpoints/rule.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

This class is deprecated. It is used by the Runtime endpoint resolution approach. It has been replaced by a code generated approach in each service gem. It can be removed in a new major version. It has to exist because old service gems can use a new core version.

API:

  • private

Direct Known Subclasses

EndpointRule, ErrorRule

Instance Method Summary collapse

Instance Method Details

#resolve_value(value, parameters, assigns) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Resolves a value that is a function, reference, or template string.

API:

  • private



13
14
15
16
17
18
19
20
21
22
# File 'lib/aws-sdk-core/endpoints/rule.rb', line 13

def resolve_value(value, parameters, assigns)
  if value.is_a?(Hash) && value['fn']
    Function.new(fn: value['fn'], argv: value['argv'])
            .call(parameters, assigns)
  elsif value.is_a?(Hash) && value['ref']
    Reference.new(ref: value['ref']).resolve(parameters, assigns)
  else
    Templater.resolve(value, parameters, assigns)
  end
end