Class: Aws::SSO::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSO::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sso/client.rb
Overview
An API client for SSO. To construct a client, you need to configure a :region and :credentials.
client = Aws::SSO::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
Attributes inherited from Seahorse::Client::Base
API Operations collapse
-
#get_role_credentials(params = {}) ⇒ Types::GetRoleCredentialsResponse
Returns the STS short-term credentials for a given role name that is assigned to the user.
-
#list_account_roles(params = {}) ⇒ Types::ListAccountRolesResponse
Lists all roles that are assigned to the user for a given AWS account.
-
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists all AWS accounts assigned to the user.
-
#logout(params = {}) ⇒ Struct
Removes the client- and server-side session that is associated with the user.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Methods included from ClientStubs
#api_requests, #next_stub, #setup_stubbing, #stub_data, #stub_responses
Methods inherited from Seahorse::Client::Base
add_plugin, api, clear_plugins, define, #inspect, new, #operation_names, plugins, remove_plugin, set_api, set_plugins
Methods included from Seahorse::Client::HandlerBuilder
#handle, #handle_request, #handle_response, #handler_for, #new_handler
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
346 347 348 |
# File 'lib/aws-sdk-sso/client.rb', line 346 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
559 560 561 |
# File 'lib/aws-sdk-sso/client.rb', line 559 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
562 563 564 |
# File 'lib/aws-sdk-sso/client.rb', line 562 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-sso/client.rb', line 537 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-core' context[:gem_version] = '3.126.0' Seahorse::Client::Request.new(handlers, context) end |
#get_role_credentials(params = {}) ⇒ Types::GetRoleCredentialsResponse
Returns the STS short-term credentials for a given role name that is assigned to the user.
392 393 394 395 |
# File 'lib/aws-sdk-sso/client.rb', line 392 def get_role_credentials(params = {}, = {}) req = build_request(:get_role_credentials, params) req.send_request() end |
#list_account_roles(params = {}) ⇒ Types::ListAccountRolesResponse
Lists all roles that are assigned to the user for a given AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
444 445 446 447 |
# File 'lib/aws-sdk-sso/client.rb', line 444 def list_account_roles(params = {}, = {}) req = build_request(:list_account_roles, params) req.send_request() end |
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists all AWS accounts assigned to the user. These AWS accounts are assigned by the administrator of the account. For more information, see [Assign User Access][1] in the *AWS SSO User Guide*. This operation returns a paginated response.
[1]: docs.aws.amazon.com/singlesignon/latest/userguide/useraccess.html#assignusers
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
500 501 502 503 |
# File 'lib/aws-sdk-sso/client.rb', line 500 def list_accounts(params = {}, = {}) req = build_request(:list_accounts, params) req.send_request() end |
#logout(params = {}) ⇒ Struct
Removes the client- and server-side session that is associated with the user.
528 529 530 531 |
# File 'lib/aws-sdk-sso/client.rb', line 528 def logout(params = {}, = {}) req = build_request(:logout, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
552 553 554 |
# File 'lib/aws-sdk-sso/client.rb', line 552 def waiter_names [] end |