Class: Aws::SSOOIDC::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSOOIDC::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssooidc/client.rb
Overview
An API client for SSOOIDC. To construct a client, you need to configure a :region and :credentials.
client = Aws::SSOOIDC::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
Attributes inherited from Seahorse::Client::Base
API Operations collapse
-
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Creates and returns an access token for the authorized client.
-
#register_client(params = {}) ⇒ Types::RegisterClientResponse
Registers a client with IAM Identity Center.
-
#start_device_authorization(params = {}) ⇒ Types::StartDeviceAuthorizationResponse
Initiates device authorization by requesting a pair of verification codes from the authorization service.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Methods included from ClientStubs
#api_requests, #next_stub, #setup_stubbing, #stub_data, #stub_responses
Methods inherited from Seahorse::Client::Base
add_plugin, api, clear_plugins, define, #inspect, new, #operation_names, plugins, remove_plugin, set_api, set_plugins
Methods included from Seahorse::Client::HandlerBuilder
#handle, #handle_request, #handle_response, #handler_for, #new_handler
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
617 618 619 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 617 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
620 621 622 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 620 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 595 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-core' context[:gem_version] = '3.181.1' Seahorse::Client::Request.new(handlers, context) end |
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Creates and returns an access token for the authorized client. The access token issued will be used to fetch short-term credentials for the assigned roles in the AWS account.
480 481 482 483 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 480 def create_token(params = {}, = {}) req = build_request(:create_token, params) req.send_request() end |
#register_client(params = {}) ⇒ Types::RegisterClientResponse
Registers a client with IAM Identity Center. This allows clients to initiate device authorization. The output should be persisted for reuse through many authentication requests.
531 532 533 534 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 531 def register_client(params = {}, = {}) req = build_request(:register_client, params) req.send_request() end |
#start_device_authorization(params = {}) ⇒ Types::StartDeviceAuthorizationResponse
Initiates device authorization by requesting a pair of verification codes from the authorization service.
586 587 588 589 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 586 def (params = {}, = {}) req = build_request(:start_device_authorization, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
610 611 612 |
# File 'lib/aws-sdk-ssooidc/client.rb', line 610 def waiter_names [] end |