Class: Aws::Signin::Types::InternalServerException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Signin::Types::InternalServerException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-signin/types.rb
Overview
Error thrown when an internal server error occurs
HTTP Status Code: 500 Internal Server Error
Used for unexpected server-side errors that prevent request processing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error ⇒ String
OAuth 2.0 error code indicating server error Will be SERVER_ERROR for internal server errors.
-
#message ⇒ String
Detailed message explaining the server error May include error details for debugging purposes.
Method Summary
Methods included from Aws::Structure
#empty?, included, #initialize, #key?, new, #to_h, #to_s
Instance Attribute Details
#error ⇒ String
OAuth 2.0 error code indicating server error Will be SERVER_ERROR for internal server errors
230 231 232 233 234 235 |
# File 'lib/aws-sdk-signin/types.rb', line 230 class InternalServerException < Struct.new( :error, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
Detailed message explaining the server error May include error details for debugging purposes
230 231 232 233 234 235 |
# File 'lib/aws-sdk-signin/types.rb', line 230 class InternalServerException < Struct.new( :error, :message) SENSITIVE = [] include Aws::Structure end |